/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2016 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp16nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp16nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2744;
INPUT
   ACCEPT  1-2              BOOKER2  3               BOOKER3  4            
   BOOKERCD  5-6            BUSCLAS  7-10            CANTPAY  11           
   CCULPSCO  12-13          CH2APP  14               CH8FINGD  15          
   CMSRVORD  16             COFI  17                 COMPLY  18-19         
   COMPLYPR  20             CRIMPURP  21             DETBFINE  22          
   DISPOSIT  23             EMPLOYNM  24             FCULPSCO  25          
   FRAUDTYP  26-27          FINSTDS  28              HISTORY  29           
   HSMISCND  30             INCORLOC  31             INCORPYR  32-35       
   INDICT  36               INPLEA1  37              INPLEA2  38           
   INPLEA3  39              INPLEA4  40              INPLEA5  41           
   INPLEA6  42              INPLEA7  43              INPLEA8  44           
   INPLEA9  45              INPLEA10  46             INPLEA11  47          
   INPLEA12  48             INNOPL1  49              INNOPL2  50           
   INNOPL3  51              INNOPL4  52              INNOPL5  53           
   INNOPL6  54              INNOPL7  55              INNOPL8  56           
   INNOPL9  57              INNOPL10  58             INNOPL11  59          
   INNOPL12  60             JANDC  61                NEWCNVTN  62          
   NOCOMP  63               NOCOUNTS  64-65          NOREAVAR  66          
   NOUSTAT  67              OBSTRUCT  68             OFFLVL  69-70         
   ORDERCE  71              ORGTYPE  72              OWNSTRCT  73-74       
   PLEA  75                 PRIMOFF  76-77           PRCIVIL  78           
   PRCRIME  79              PROBATN  80-81           PROBMON  82           
   PSR  83                  QUARTER  84              REAS1  85-88          
   REAS2  89-91             REAS3  92-94             REAS4  95-97          
   REAS5  98-100            REAS6  101-103           REASONS  104          
   REMEDORD  105            SELFREP  106             SOURCES  107          
   TOLERNCE  108            TYPEOTHS  109-110        VICTNOTE  111         
   VIOLATE  112             AMENDYR  113-116         SENTYR  117-120       
   BASEFINE  121-129        COSTASSM  130            DISGORGE  131         
   FINOFFST  132            FORFEITR  133-139        GLFINMAX  140-149     
   GLFINMIN  150-158        STATMIN  159-162         STATMAX  163-171      
   RESTCAT  172             FINECAT  173             SUSFNCAT  174         
   LCAT1  175               LCAT2  176               LCATHI  177           
   LCATS1  178              LCATS2  179              LCATSHI  180          
   LCATR1  181              LCATR2  182              LCATRHI  183          
   LCATC1  184              LCATC2  185              LCATCHI  186          
   LCATU1  187              LCATU2  188              LCATUHI  189          
   CPIDN  190-196           BUSTEXT $ 197-248        FINSTXT $ 249-312     
   OWNSTEXT $ 313-346       PRMONTXT $ 347-435       ORDERTXT $ 436-631    
   TYPEOTTX $ 632-877       MINFINML  878-881        MAXFINML  882-884     
   ADJOFL1  885-886         ADJOFL2  887-888         ADJOFLHI  889-890     
   ADJ_B1  891-892          ADJ_B2  893-894          ADJ_BHI  895-896      
   ADJ_C1  897-898          ADJ_C2  899              ADJ_CHI  900-901      
   ADJ_D1  902              ADJ_D2  903              ADJ_DHI  904          
   ADJ_E1  905              ADJ_E2  906              ADJ_EHI  907          
   ADJ_F1  908              ADJ_F2  909              ADJ_FHI  910          
   ADJ_G1  911              ADJ_G2  912              ADJ_GHI  913          
   ADJ_H1  914              ADJ_H2  915              ADJ_HHI  916          
   ADJ_I1  917              ADJ_I2  918              ADJ_IHI  919          
   ADJ_J1  920              ADJ_J2  921              ADJ_JHI  922          
   ADJ_K1  923              ADJ_K2  924              ADJ_KHI  925          
   ADJ_L1  926              ADJ_L2  927              ADJ_LHI  928          
   ADJ_M1  929              ADJ_M2  930              ADJ_MHI  931          
   ADJ_N1  932              ADJ_N2  933              ADJ_NHI  934          
   ADJ_O1  935              ADJ_O2  936              ADJ_OHI  937          
   ADJ_P1  938              ADJ_P2  939              ADJ_PHI  940          
   ADJ_Q1  941              ADJ_Q2  942              ADJ_QHI  943          
   ADJ_R1  944-945          ADJ_R2  946              ADJ_RHI  947-948      
   ADJ_S1  949              ADJ_S2  950              ADJ_SHI  951          
   ADJ_T1  952              ADJ_T2  953              ADJ_THI  954          
   BASADJ1  955-956         BASADJ2  957-958         BASADJHI  959-960     
   BASE1  961-962           BASE2  963-964           BASEHI  965-966       
   HUMAN1  967              HUMAN2  968              HUMANHI  969          
   BASLN1  970              BASLN2  971              BASLNHI  972          
   ADJOFS1  973-974         ADJOFS2  975-976         ADJOFSHI  977-978     
   ADJS_B1  979-980         ADJS_B2  981-982         ADJS_BHI  983-984     
   ADJS_C1  985-986         ADJS_C2  987             ADJS_CHI  988-989     
   ADJS_D1  990             ADJS_D2  991             ADJS_DHI  992         
   ADJS_E1  993             ADJS_E2  994             ADJS_EHI  995         
   ADJS_F1  996             ADJS_F2  997             ADJS_FHI  998         
   ADJS_G1  999             ADJS_G2  1000            ADJS_GHI  1001        
   ADJS_H1  1002            ADJS_H2  1003            ADJS_HHI  1004        
   ADJS_I1  1005            ADJS_I2  1006            ADJS_IHI  1007        
   ADJS_J1  1008            ADJS_J2  1009            ADJS_JHI  1010        
   ADJS_K1  1011            ADJS_K2  1012            ADJS_KHI  1013        
   ADJS_L1  1014            ADJS_L2  1015            ADJS_LHI  1016        
   ADJS_M1  1017            ADJS_M2  1018            ADJS_MHI  1019        
   ADJS_N1  1020            ADJS_N2  1021            ADJS_NHI  1022        
   ADJS_O1  1023            ADJS_O2  1024            ADJS_OHI  1025        
   ADJS_P1  1026            ADJS_P2  1027            ADJS_PHI  1028        
   ADJS_Q1  1029            ADJS_Q2  1030            ADJS_QHI  1031        
   ADJS_R1  1032-1033       ADJS_R2  1034            ADJS_RHI  1035-1036   
   ADJS_S1  1037            ADJS_S2  1038            ADJS_SHI  1039        
   ADJS_T1  1040            ADJS_T2  1041            ADJS_THI  1042        
   BASADS1  1043-1044       BASADS2  1045-1046       BASADSHI  1047-1048   
   BASES1  1049-1050        BASES2  1051-1052        BASESHI  1053-1054    
   HUMANS1  1055            HUMANS2  1056            HUMANSHI  1057        
   BASLNS1  1058            BASLNS2  1059            BASLNSHI  1060        
   ADJOFR1  1061-1062       ADJOFR2  1063            ADJOFRHI  1064-1065   
   ADJR_B1  1066-1067       ADJR_B2  1068            ADJR_BHI  1069-1070   
   ADJR_C1  1071-1072       ADJR_C2  1073            ADJR_CHI  1074-1075   
   ADJR_D1  1076            ADJR_D2  1077            ADJR_DHI  1078        
   ADJR_E1  1079            ADJR_E2  1080            ADJR_EHI  1081        
   ADJR_F1  1082            ADJR_F2  1083            ADJR_FHI  1084        
   ADJR_G1  1085            ADJR_G2  1086            ADJR_GHI  1087        
   ADJR_H1  1088            ADJR_H2  1089            ADJR_HHI  1090        
   ADJR_I1  1091            ADJR_I2  1092            ADJR_IHI  1093        
   ADJR_J1  1094            ADJR_J2  1095            ADJR_JHI  1096        
   ADJR_K1  1097            ADJR_K2  1098            ADJR_KHI  1099        
   ADJR_L1  1100            ADJR_L2  1101            ADJR_LHI  1102        
   ADJR_M1  1103            ADJR_M2  1104            ADJR_MHI  1105        
   ADJR_N1  1106            ADJR_N2  1107            ADJR_NHI  1108        
   ADJR_O1  1109            ADJR_O2  1110            ADJR_OHI  1111        
   ADJR_P1  1112            ADJR_P2  1113            ADJR_PHI  1114        
   ADJR_Q1  1115            ADJR_Q2  1116            ADJR_QHI  1117        
   ADJR_R1  1118            ADJR_R2  1119            ADJR_RHI  1120        
   ADJR_S1  1121            ADJR_S2  1122            ADJR_SHI  1123        
   ADJR_T1  1124            ADJR_T2  1125            ADJR_THI  1126        
   BASADR1  1127            BASADR2  1128            BASADRHI  1129        
   BASER1  1130-1131        BASER2  1132             BASERHI  1133-1134    
   HUMANR1  1135            HUMANR2  1136            HUMANRHI  1137        
   BASLNR1  1138            BASLNR2  1139            BASLNRHI  1140        
   ADJOFC1  1141            ADJOFC2  1142            ADJOFCHI  1143        
   ADJC_B1  1144            ADJC_B2  1145            ADJC_BHI  1146        
   ADJC_C1  1147            ADJC_C2  1148            ADJC_CHI  1149        
   ADJC_D1  1150            ADJC_D2  1151            ADJC_DHI  1152        
   ADJC_E1  1153            ADJC_E2  1154            ADJC_EHI  1155        
   ADJC_F1  1156            ADJC_F2  1157            ADJC_FHI  1158        
   ADJC_G1  1159            ADJC_G2  1160            ADJC_GHI  1161        
   ADJC_H1  1162            ADJC_H2  1163            ADJC_HHI  1164        
   ADJC_I1  1165            ADJC_I2  1166            ADJC_IHI  1167        
   ADJC_J1  1168            ADJC_J2  1169            ADJC_JHI  1170        
   ADJC_K1  1171            ADJC_K2  1172            ADJC_KHI  1173        
   ADJC_L1  1174            ADJC_L2  1175            ADJC_LHI  1176        
   ADJC_M1  1177            ADJC_M2  1178            ADJC_MHI  1179        
   ADJC_N1  1180            ADJC_N2  1181            ADJC_NHI  1182        
   ADJC_O1  1183            ADJC_O2  1184            ADJC_OHI  1185        
   ADJC_P1  1186            ADJC_P2  1187            ADJC_PHI  1188        
   ADJC_Q1  1189            ADJC_Q2  1190            ADJC_QHI  1191        
   ADJC_R1  1192            ADJC_R2  1193            ADJC_RHI  1194        
   ADJC_S1  1195            ADJC_S2  1196            ADJC_SHI  1197        
   ADJC_T1  1198            ADJC_T2  1199            ADJC_THI  1200        
   BASADC1  1201            BASADC2  1202            BASADCHI  1203        
   BASEC1  1204             BASEC2  1205             BASECHI  1206         
   HUMANC1  1207            HUMANC2  1208            HUMANCHI  1209        
   BASLNC1  1210            BASLNC2  1211            BASLNCHI  1212        
   ADJOFU1  1213            ADJOFU2  1214            ADJOFUHI  1215        
   ADJU_B1  1216            ADJU_B2  1217            ADJU_BHI  1218        
   ADJU_C1  1219            ADJU_C2  1220            ADJU_CHI  1221        
   ADJU_D1  1222            ADJU_D2  1223            ADJU_DHI  1224        
   ADJU_E1  1225            ADJU_E2  1226            ADJU_EHI  1227        
   ADJU_F1  1228            ADJU_F2  1229            ADJU_FHI  1230        
   ADJU_G1  1231            ADJU_G2  1232            ADJU_GHI  1233        
   ADJU_H1  1234            ADJU_H2  1235            ADJU_HHI  1236        
   ADJU_I1  1237            ADJU_I2  1238            ADJU_IHI  1239        
   ADJU_J1  1240            ADJU_J2  1241            ADJU_JHI  1242        
   ADJU_K1  1243            ADJU_K2  1244            ADJU_KHI  1245        
   ADJU_L1  1246            ADJU_L2  1247            ADJU_LHI  1248        
   ADJU_M1  1249            ADJU_M2  1250            ADJU_MHI  1251        
   ADJU_N1  1252            ADJU_N2  1253            ADJU_NHI  1254        
   ADJU_O1  1255            ADJU_O2  1256            ADJU_OHI  1257        
   ADJU_P1  1258            ADJU_P2  1259            ADJU_PHI  1260        
   ADJU_Q1  1261            ADJU_Q2  1262            ADJU_QHI  1263        
   ADJU_R1  1264            ADJU_R2  1265            ADJU_RHI  1266        
   ADJU_S1  1267            ADJU_S2  1268            ADJU_SHI  1269        
   ADJU_T1  1270            ADJU_T2  1271            ADJU_THI  1272        
   BASADU1  1273            BASADU2  1274            BASADUHI  1275        
   BASEU1  1276             BASEU2  1277             BASEUHI  1278         
   HUMANU1  1279            HUMANU2  1280            HUMANUHI  1281        
   BASLNU1  1282            BASLNU2  1283            BASLNUHI  1284        
   ADJL_B1 $ 1285           ADJL_B2 $ 1286           ADJL_BHI $ 1287       
   ADJL_C1 $ 1288-1289      ADJL_C2 $ 1290           ADJL_CHI $ 1291-1292  
   ADJL_D1 $ 1293           ADJL_D2 $ 1294           ADJL_DHI $ 1295       
   ADJL_E1 $ 1296           ADJL_E2 $ 1297           ADJL_EHI $ 1298       
   ADJL_F1 $ 1299           ADJL_F2 $ 1300           ADJL_FHI $ 1301       
   ADJL_G1 $ 1302           ADJL_G2 $ 1303           ADJL_GHI $ 1304       
   ADJL_H1 $ 1305-1306      ADJL_H2 $ 1307           ADJL_HHI $ 1308-1309  
   ADJL_I1 $ 1310           ADJL_I2 $ 1311           ADJL_IHI $ 1312       
   ADJL_J1 $ 1313           ADJL_J2 $ 1314           ADJL_JHI $ 1315       
   ADJL_K1 $ 1316           ADJL_K2 $ 1317           ADJL_KHI $ 1318       
   ADJL_L1 $ 1319-1320      ADJL_L2 $ 1321           ADJL_LHI $ 1322-1323  
   ADJL_M1 $ 1324           ADJL_M2 $ 1325           ADJL_MHI $ 1326       
   ADJL_N1 $ 1327           ADJL_N2 $ 1328           ADJL_NHI $ 1329       
   ADJL_O1 $ 1330           ADJL_O2 $ 1331           ADJL_OHI $ 1332       
   ADJL_P1 $ 1333           ADJL_P2 $ 1334           ADJL_PHI $ 1335       
   ADJL_Q1 $ 1336           ADJL_Q2 $ 1337           ADJL_QHI $ 1338       
   ADJL_R1 $ 1339           ADJL_R2 $ 1340           ADJL_RHI $ 1341       
   ADJL_S1 $ 1342           ADJL_S2 $ 1343           ADJL_SHI $ 1344       
   ADJL_T1 $ 1345           ADJL_T2 $ 1346           ADJL_THI $ 1347       
   BASEL1 $ 1348            BASEL2 $ 1349            BASELHI $ 1350        
   HUMLB1 $ 1351            HUMLB2 $ 1352            HUMLBHI $ 1353        
   ADSL_B1 $ 1354           ADSL_B2 $ 1355           ADSL_BHI $ 1356       
   ADSL_C1 $ 1357           ADSL_C2 $ 1358           ADSL_CHI $ 1359       
   ADSL_D1 $ 1360           ADSL_D2 $ 1361           ADSL_DHI $ 1362       
   ADSL_E1 $ 1363           ADSL_E2 $ 1364           ADSL_EHI $ 1365       
   ADSL_F1 $ 1366           ADSL_F2 $ 1367           ADSL_FHI $ 1368       
   ADSL_G1 $ 1369           ADSL_G2 $ 1370           ADSL_GHI $ 1371       
   ADSL_H1 $ 1372-1373      ADSL_H2 $ 1374           ADSL_HHI $ 1375-1376  
   ADSL_I1 $ 1377           ADSL_I2 $ 1378           ADSL_IHI $ 1379       
   ADSL_J1 $ 1380           ADSL_J2 $ 1381           ADSL_JHI $ 1382       
   ADSL_K1 $ 1383           ADSL_K2 $ 1384           ADSL_KHI $ 1385       
   ADSL_L1 $ 1386-1387      ADSL_L2 $ 1388           ADSL_LHI $ 1389-1390  
   ADSL_M1 $ 1391           ADSL_M2 $ 1392           ADSL_MHI $ 1393       
   ADSL_N1 $ 1394           ADSL_N2 $ 1395           ADSL_NHI $ 1396       
   ADSL_O1 $ 1397           ADSL_O2 $ 1398           ADSL_OHI $ 1399       
   ADSL_P1 $ 1400           ADSL_P2 $ 1401           ADSL_PHI $ 1402       
   ADSL_Q1 $ 1403           ADSL_Q2 $ 1404           ADSL_QHI $ 1405       
   ADSL_R1 $ 1406           ADSL_R2 $ 1407           ADSL_RHI $ 1408       
   ADSL_S1 $ 1409           ADSL_S2 $ 1410           ADSL_SHI $ 1411       
   ADSL_T1 $ 1412           ADSL_T2 $ 1413           ADSL_THI $ 1414       
   BASESL1 $ 1415           BASESL2 $ 1416           BASESLHI $ 1417       
   HUMLBS1 $ 1418           HUMLBS2 $ 1419           HUMLBSHI $ 1420       
   ADRL_B1 $ 1421           ADRL_B2 $ 1422           ADRL_BHI $ 1423       
   ADRL_C1 $ 1424-1425      ADRL_C2 $ 1426           ADRL_CHI $ 1427-1428  
   ADRL_D1 $ 1429           ADRL_D2 $ 1430           ADRL_DHI $ 1431       
   ADRL_E1 $ 1432           ADRL_E2 $ 1433           ADRL_EHI $ 1434       
   ADRL_F1 $ 1435           ADRL_F2 $ 1436           ADRL_FHI $ 1437       
   ADRL_G1 $ 1438           ADRL_G2 $ 1439           ADRL_GHI $ 1440       
   ADRL_H1 $ 1441           ADRL_H2 $ 1442           ADRL_HHI $ 1443       
   ADRL_I1 $ 1444           ADRL_I2 $ 1445           ADRL_IHI $ 1446       
   ADRL_J1 $ 1447           ADRL_J2 $ 1448           ADRL_JHI $ 1449       
   ADRL_K1 $ 1450           ADRL_K2 $ 1451           ADRL_KHI $ 1452       
   ADRL_L1 $ 1453           ADRL_L2 $ 1454           ADRL_LHI $ 1455       
   ADRL_M1 $ 1456           ADRL_M2 $ 1457           ADRL_MHI $ 1458       
   ADRL_N1 $ 1459           ADRL_N2 $ 1460           ADRL_NHI $ 1461       
   ADRL_O1 $ 1462           ADRL_O2 $ 1463           ADRL_OHI $ 1464       
   ADRL_P1 $ 1465           ADRL_P2 $ 1466           ADRL_PHI $ 1467       
   ADRL_Q1 $ 1468           ADRL_Q2 $ 1469           ADRL_QHI $ 1470       
   ADRL_R1 $ 1471           ADRL_R2 $ 1472           ADRL_RHI $ 1473       
   ADRL_S1 $ 1474           ADRL_S2 $ 1475           ADRL_SHI $ 1476       
   ADRL_T1 $ 1477           ADRL_T2 $ 1478           ADRL_THI $ 1479       
   BASERL1 $ 1480           BASERL2 $ 1481           BASERLHI $ 1482       
   HUMLBR1 $ 1483           HUMLBR2 $ 1484           HUMLBRHI $ 1485       
   ADCL_B1 $ 1486           ADCL_B2 $ 1487           ADCL_BHI $ 1488       
   ADCL_C1 $ 1489           ADCL_C2 $ 1490           ADCL_CHI $ 1491       
   ADCL_D1 $ 1492           ADCL_D2 $ 1493           ADCL_DHI $ 1494       
   ADCL_E1 $ 1495           ADCL_E2 $ 1496           ADCL_EHI $ 1497       
   ADCL_F1 $ 1498           ADCL_F2 $ 1499           ADCL_FHI $ 1500       
   ADCL_G1 $ 1501           ADCL_G2 $ 1502           ADCL_GHI $ 1503       
   ADCL_H1 $ 1504           ADCL_H2 $ 1505           ADCL_HHI $ 1506       
   ADCL_I1 $ 1507           ADCL_I2 $ 1508           ADCL_IHI $ 1509       
   ADCL_J1 $ 1510           ADCL_J2 $ 1511           ADCL_JHI $ 1512       
   ADCL_K1 $ 1513           ADCL_K2 $ 1514           ADCL_KHI $ 1515       
   ADCL_L1 $ 1516           ADCL_L2 $ 1517           ADCL_LHI $ 1518       
   ADCL_M1 $ 1519           ADCL_M2 $ 1520           ADCL_MHI $ 1521       
   ADCL_N1 $ 1522           ADCL_N2 $ 1523           ADCL_NHI $ 1524       
   ADCL_O1 $ 1525           ADCL_O2 $ 1526           ADCL_OHI $ 1527       
   ADCL_P1 $ 1528           ADCL_P2 $ 1529           ADCL_PHI $ 1530       
   ADCL_Q1 $ 1531           ADCL_Q2 $ 1532           ADCL_QHI $ 1533       
   ADCL_R1 $ 1534           ADCL_R2 $ 1535           ADCL_RHI $ 1536       
   ADCL_S1 $ 1537           ADCL_S2 $ 1538           ADCL_SHI $ 1539       
   ADCL_T1 $ 1540           ADCL_T2 $ 1541           ADCL_THI $ 1542       
   BASECL1 $ 1543           BASECL2 $ 1544           BASECLHI $ 1545       
   HUMLBC1 $ 1546           HUMLBC2 $ 1547           HUMLBCHI $ 1548       
   ADUL_B1 $ 1549           ADUL_B2 $ 1550           ADUL_BHI $ 1551       
   ADUL_C1 $ 1552           ADUL_C2 $ 1553           ADUL_CHI $ 1554       
   ADUL_D1 $ 1555           ADUL_D2 $ 1556           ADUL_DHI $ 1557       
   ADUL_E1 $ 1558           ADUL_E2 $ 1559           ADUL_EHI $ 1560       
   ADUL_F1 $ 1561           ADUL_F2 $ 1562           ADUL_FHI $ 1563       
   ADUL_G1 $ 1564           ADUL_G2 $ 1565           ADUL_GHI $ 1566       
   ADUL_H1 $ 1567           ADUL_H2 $ 1568           ADUL_HHI $ 1569       
   ADUL_I1 $ 1570           ADUL_I2 $ 1571           ADUL_IHI $ 1572       
   ADUL_J1 $ 1573           ADUL_J2 $ 1574           ADUL_JHI $ 1575       
   ADUL_K1 $ 1576           ADUL_K2 $ 1577           ADUL_KHI $ 1578       
   ADUL_L1 $ 1579           ADUL_L2 $ 1580           ADUL_LHI $ 1581       
   ADUL_M1 $ 1582           ADUL_M2 $ 1583           ADUL_MHI $ 1584       
   ADUL_N1 $ 1585           ADUL_N2 $ 1586           ADUL_NHI $ 1587       
   ADUL_O1 $ 1588           ADUL_O2 $ 1589           ADUL_OHI $ 1590       
   ADUL_P1 $ 1591           ADUL_P2 $ 1592           ADUL_PHI $ 1593       
   ADUL_Q1 $ 1594           ADUL_Q2 $ 1595           ADUL_QHI $ 1596       
   ADUL_R1 $ 1597           ADUL_R2 $ 1598           ADUL_RHI $ 1599       
   ADUL_S1 $ 1600           ADUL_S2 $ 1601           ADUL_SHI $ 1602       
   ADUL_T1 $ 1603           ADUL_T2 $ 1604           ADUL_THI $ 1605       
   BASEUL1 $ 1606           BASEUL2 $ 1607           BASEULHI $ 1608       
   HUMLBU1 $ 1609           HUMLBU2 $ 1610           HUMLBUHI $ 1611       
   GDLINE1 $ 1612-1616      GDLINE2 $ 1617-1621      GDSTAT1 $ 1622-1626   
   GDSTAT2 $ 1627-1631      GDREF1 $ 1632-1636       GDREF2 $ 1637         
   GDCROS1 $ 1638           GDCROS2 $ 1639           GDUNDR1 $ 1640        
   GDUNDR2 $ 1641           GDLINEHI $ 1642-1646     GDSTATHI $ 1647-1651  
   GDREFHI $ 1652-1656      GDCROSHI $ 1657          GDUNDRHI $ 1658       
   STA1_1 $ 1659-1668       STA1_2 $ 1669-1677       STA1_3 $ 1678-1688    
   STA1_4 $ 1689-1697       STA1_5 $ 1698-1703       STA1_6 $ 1704-1710    
   STA1_7 $ 1711-1716       STA1_8 $ 1717-1722       STA1_9 $ 1723-1728    
   STA1_10 $ 1729-1734      STA1_11 $ 1735-1740      STA1_12 $ 1741-1749   
   STA1_13 $ 1750-1758      STA1_14 $ 1759-1767      STA1_15 $ 1768-1776   
   STA1_16 $ 1777-1785      STA1_17 $ 1786-1794      STA1_18 $ 1795-1803   
   STA1_19 $ 1804-1812      STA1_20 $ 1813-1821      STA1_21 $ 1822-1830   
   STA1_22 $ 1831-1839      STA1_23 $ 1840-1845      STA1_24 $ 1846-1851   
   STA1_25 $ 1852-1857      STA1_26 $ 1858-1863      STA1_27 $ 1864-1869   
   STA1_28 $ 1870-1875      STA1_29 $ 1876-1881      STA1_30 $ 1882-1887   
   STA1_31 $ 1888-1893      STA1_32 $ 1894-1899      STA1_33 $ 1900-1905   
   STA1_34 $ 1906-1911      STA1_35 $ 1912-1917      STA1_36 $ 1918-1923   
   STA1_37 $ 1924-1929      STA1_38 $ 1930-1935      STA2_1 $ 1936-1946    
   STA2_2 $ 1947-1954       STA2_3 $ 1955-1962       STA2_4 $ 1963-1968    
   STA2_5 $ 1969-1971       STA2_6 $ 1972-1974       STA2_7 $ 1975-1977    
   STA2_8 $ 1978-1980       STA2_9 $ 1981-1983       STA2_10 $ 1984-1986   
   STA2_11 $ 1987-1989      STA2_12 $ 1990-1992      STA2_13 $ 1993-1995   
   STA2_14 $ 1996-1998      STA2_15 $ 1999-2001      STA2_16 $ 2002-2004   
   STA2_17 $ 2005-2007      STA2_18 $ 2008-2010      STA2_19 $ 2011-2013   
   STA2_20 $ 2014-2016      STA2_21 $ 2017-2019      STA2_22 $ 2020-2022   
   STA2_23 $ 2023-2025      STA2_24 $ 2026-2028      STA2_25 $ 2029-2031   
   STA2_26 $ 2032-2034      STA2_27 $ 2035-2037      STA2_28 $ 2038-2040   
   STA2_29 $ 2041-2043      STA2_30 $ 2044-2046      STA2_31 $ 2047-2049   
   STA2_32 $ 2050-2052      STA2_33 $ 2053-2055      STA2_34 $ 2056-2058   
   STA2_35 $ 2059-2061      STA2_36 $ 2062-2064      STA2_37 $ 2065-2067   
   STA2_38 $ 2068-2070      STA3_1 $ 2071-2080       STA3_2 $ 2081-2090    
   STA3_3 $ 2091-2096       STA3_4 $ 2097            STA3_5 $ 2098         
   STA3_6 $ 2099            STA3_7 $ 2100            STA3_8 $ 2101         
   STA3_9 $ 2102            STA3_10 $ 2103           STA3_11 $ 2104        
   STA3_12 $ 2105           STA3_13 $ 2106           STA3_14 $ 2107        
   STA3_15 $ 2108           STA3_16 $ 2109           STA3_17 $ 2110        
   STA3_18 $ 2111           STA3_19 $ 2112           STA3_20 $ 2113        
   STA3_21 $ 2114           STA3_22 $ 2115           STA3_23 $ 2116        
   STA3_24 $ 2117           STA3_25 $ 2118           STA3_26 $ 2119        
   STA3_27 $ 2120           STA3_28 $ 2121           STA3_29 $ 2122        
   STA3_30 $ 2123           STA3_31 $ 2124           STA3_32 $ 2125        
   STA3_33 $ 2126           STA3_34 $ 2127           STA3_35 $ 2128        
   STA3_36 $ 2129           STA3_37 $ 2130           STA3_38 $ 2131        
   NWSTAT1 $ 2132-2141      NWSTAT2 $ 2142-2152      NWSTAT3 $ 2153-2163   
   NWSTAT4 $ 2164-2173      NWSTAT5 $ 2174-2179      NWSTAT6 $ 2180-2185   
   SMAX1  2186-2194         SMAX2  2195-2202         SMAX3  2203-2209      
   SMAX4  2210-2216         SMAX5  2217-2222         SMAX6  2223-2228      
   SMAX7  2229-2234         SMAX8  2235-2240         SMAX9  2241-2246      
   SMAX10  2247-2252        SMAX11  2253-2258        SMAX12  2259-2264     
   SMAX13  2265-2270        SMAX14  2271-2276        SMAX15  2277-2282     
   SMAX16  2283-2288        SMAX17  2289-2294        SMAX18  2295-2300     
   SMAX19  2301-2306        SMAX20  2307-2312        SMAX21  2313-2318     
   SMAX22  2319-2324        SMAX23  2325-2330        SMAX24  2331-2336     
   SMAX25  2337-2342        SMAX26  2343-2348        SMAX27  2349-2354     
   SMAX28  2355-2360        SMAX29  2361-2366        SMAX30  2367-2372     
   SMAX31  2373-2378        SMAX32  2379-2384        SMAX33  2385-2390     
   SMAX34  2391-2396        SMAX35  2397-2402        SMAX36  2403-2408     
   SMAX37  2409-2414        SMAX38  2415-2420        SMIN1  2421-2424      
   SMIN2  2425-2428         SMIN3  2429-2432         SMIN4  2433-2436      
   SMIN5  2437              SMIN6  2438              SMIN7  2439           
   SMIN8  2440              SMIN9  2441              SMIN10  2442          
   SMIN11  2443             SMIN12  2444             SMIN13  2445          
   SMIN14  2446             SMIN15  2447             SMIN16  2448          
   SMIN17  2449             SMIN18  2450             SMIN19  2451          
   SMIN20  2452             SMIN21  2453             SMIN22  2454          
   SMIN23  2455             SMIN24  2456             SMIN25  2457          
   SMIN26  2458             SMIN27  2459             SMIN28  2460          
   SMIN29  2461             SMIN30  2462             SMIN31  2463          
   SMIN32  2464             SMIN33  2465             SMIN34  2466          
   SMIN35  2467             SMIN36  2468             SMIN37  2469          
   SMIN38  2470             RETEXT1 $ 2471-2577      RETEXT2 $ 2578-2659   
   RETEXT3 $ 2660-2720      RETEXT4 $ 2721           RETEXT5 $ 2722-2743   
   RETEXT6 $ 2744         ;                       

LABEL
   ACCEPT = "ACCEPT"
   BUSCLAS = "BUSCLAS"
   CANTPAY = "CANTPAY"
   CCULPSCO = "CCULPSCO"
   CH2APP = "CH2APP"
   CH8FINGD = "CH8FINGD"
   CMSRVORD = "CMSRVORD"
   COFI = "COFI"
   COMPLY = "COMPLY"
   COMPLYPR = "COMPLYPR"
   CRIMPURP = "CRIMPURP"
   DETBFINE = "DETBFINE"
   DISPOSIT = "DISPOSIT"
   EMPLOYNM = "FTEMNUM"
   FCULPSCO = "FCULPSCO"
   FRAUDTYP = "FRAUDTYP"
   FINSTDS = "FINSTDS"
   HISTORY = "HISTORY"
   HSMISCND = "HSMISCND"
   INCORLOC = "INCORLOC"
   INCORPYR = "INCORPYR"
   INDICT = "INDICT"
   JANDC = "JANDC"
   NOCOUNTS = "NOCOUNTS"
   OBSTRUCT = "OBSTRUCT"
   OFFLVL = "OFFLVL"
   ORDERCE = "ORDERCE"
   ORGTYPE = "ORGTYPE"
   PLEA = "PLEA"
   PRIMOFF = "OFFTYPE"
   PRCIVIL = "PRCIVIL"
   PRCRIME = "PRCRIME"
   PROBATN = "PROBATN"
   PROBMON = "PROBMON"
   PSR = "PSR"
   REASONS = "REASONS"
   REMEDORD = "REMEDORD"
   SELFREP = "SELFREP"
   SOURCES = "SOURCES"
   TOLERNCE = "TOLERNCE"
   TYPEOTHS = "TYPEOTHS"
   VICTNOTE = "VICTNOTE"
   VIOLATE = "VIOLATE"
   AMENDYR = "AMENDYR"
   BASEFINE = "BASEFINE"
   COSTASSM = "COSTASSM"
   DISGORGE = "DISGORGE"
   FINOFFST = "FINOFFST"
   FORFEITR = "FORFEITR"
   GLFINMAX = "GLFINMAX"
   GLFINMIN = "GLFINMIN"
   CPIDN = "CPIDN"
   BUSTEXT = "BUSTEXT"
   FINSTXT = "FINSTXT"
   OWNSTEXT = "OWNSTEXT"
   PRMONTXT = "PRMONTXT"
   ORDERTXT = "ORDERTXT"
   TYPEOTTX = "TYPOTXT"
   MINFINML = "MINFINML"
   MAXFINML = "MAXFINML"
;

LENGTH
   ACCEPT 3                 BOOKER2 3                BOOKER3 3             
   BOOKERCD 3               BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 4                  REAS4 4               
   REAS5 4                  REAS6 4                  REASONS 3             
   REMEDORD 3               SELFREP 3                SOURCES 3             
   TOLERNCE 3               TYPEOTHS 3               VICTNOTE 3            
   VIOLATE 3                AMENDYR 4                SENTYR 4              
   BASEFINE 6               COSTASSM 3               DISGORGE 3            
   FINOFFST 3               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               STATMIN 4                STATMAX 6             
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATSHI 3             
   LCATR1 3                 LCATR2 3                 LCATRHI 3             
   LCATC1 3                 LCATC2 3                 LCATCHI 3             
   LCATU1 3                 LCATU2 3                 LCATUHI 3             
   CPIDN 6                  ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                ADJ_Q1 3                 ADJ_Q2 3              
   ADJ_QHI 3                ADJ_R1 3                 ADJ_R2 3              
   ADJ_RHI 3                ADJ_S1 3                 ADJ_S2 3              
   ADJ_SHI 3                ADJ_T1 3                 ADJ_T2 3              
   ADJ_THI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 HUMAN1 3                 HUMAN2 3              
   HUMANHI 3                BASLN1 3                 BASLN2 3              
   BASLNHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               ADJS_Q1 3                ADJS_Q2 3             
   ADJS_QHI 3               ADJS_R1 3                ADJS_R2 3             
   ADJS_RHI 3               ADJS_S1 3                ADJS_S2 3             
   ADJS_SHI 3               ADJS_T1 3                ADJS_T2 3             
   ADJS_THI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                HUMANS1 3                HUMANS2 3             
   HUMANSHI 3               BASLNS1 3                BASLNS2 3             
   BASLNSHI 3               ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               ADJR_Q1 3                ADJR_Q2 3             
   ADJR_QHI 3               ADJR_R1 3                ADJR_R2 3             
   ADJR_RHI 3               ADJR_S1 3                ADJR_S2 3             
   ADJR_SHI 3               ADJR_T1 3                ADJR_T2 3             
   ADJR_THI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                HUMANR1 3                HUMANR2 3             
   HUMANRHI 3               BASLNR1 3                BASLNR2 3             
   BASLNRHI 3               ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               ADJC_Q1 3                ADJC_Q2 3             
   ADJC_QHI 3               ADJC_R1 3                ADJC_R2 3             
   ADJC_RHI 3               ADJC_S1 3                ADJC_S2 3             
   ADJC_SHI 3               ADJC_T1 3                ADJC_T2 3             
   ADJC_THI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                HUMANC1 3                HUMANC2 3             
   HUMANCHI 3               BASLNC1 3                BASLNC2 3             
   BASLNCHI 3               ADJOFU1 3                ADJOFU2 3             
   ADJOFUHI 3               ADJU_B1 3                ADJU_B2 3             
   ADJU_BHI 3               ADJU_C1 3                ADJU_C2 3             
   ADJU_CHI 3               ADJU_D1 3                ADJU_D2 3             
   ADJU_DHI 3               ADJU_E1 3                ADJU_E2 3             
   ADJU_EHI 3               ADJU_F1 3                ADJU_F2 3             
   ADJU_FHI 3               ADJU_G1 3                ADJU_G2 3             
   ADJU_GHI 3               ADJU_H1 3                ADJU_H2 3             
   ADJU_HHI 3               ADJU_I1 3                ADJU_I2 3             
   ADJU_IHI 3               ADJU_J1 3                ADJU_J2 3             
   ADJU_JHI 3               ADJU_K1 3                ADJU_K2 3             
   ADJU_KHI 3               ADJU_L1 3                ADJU_L2 3             
   ADJU_LHI 3               ADJU_M1 3                ADJU_M2 3             
   ADJU_MHI 3               ADJU_N1 3                ADJU_N2 3             
   ADJU_NHI 3               ADJU_O1 3                ADJU_O2 3             
   ADJU_OHI 3               ADJU_P1 3                ADJU_P2 3             
   ADJU_PHI 3               ADJU_Q1 3                ADJU_Q2 3             
   ADJU_QHI 3               ADJU_R1 3                ADJU_R2 3             
   ADJU_RHI 3               ADJU_S1 3                ADJU_S2 3             
   ADJU_SHI 3               ADJU_T1 3                ADJU_T2 3             
   ADJU_THI 3               BASADU1 3                BASADU2 3             
   BASADUHI 3               BASEU1 3                 BASEU2 3              
   BASEUHI 3                HUMANU1 3                HUMANU2 3             
   HUMANUHI 3               BASLNU1 3                BASLNU2 3             
   BASLNUHI 3               SMAX1 6                  SMAX2 6               
   SMAX3 6                  SMAX4 6                  SMAX5 6               
   SMAX6 6                  SMAX7 6                  SMAX8 6               
   SMAX9 6                  SMAX10 6                 SMAX11 6              
   SMAX12 6                 SMAX13 6                 SMAX14 6              
   SMAX15 6                 SMAX16 6                 SMAX17 6              
   SMAX18 6                 SMAX19 6                 SMAX20 6              
   SMAX21 6                 SMAX22 6                 SMAX23 6              
   SMAX24 6                 SMAX25 6                 SMAX26 6              
   SMAX27 6                 SMAX28 6                 SMAX29 6              
   SMAX30 6                 SMAX31 6                 SMAX32 6              
   SMAX33 6                 SMAX34 6                 SMAX35 6              
   SMAX36 6                 SMAX37 6                 SMAX38 6              
   SMIN1 4                  SMIN2 4                  SMIN3 4               
   SMIN4 4                  SMIN5 3                  SMIN6 3               
   SMIN7 3                  SMIN8 3                  SMIN9 3               
   SMIN10 3                 SMIN11 3                 SMIN12 3              
   SMIN13 3                 SMIN14 3                 SMIN15 3              
   SMIN16 3                 SMIN17 3                 SMIN18 3              
   SMIN19 3                 SMIN20 3                 SMIN21 3              
   SMIN22 3                 SMIN23 3                 SMIN24 3              
   SMIN25 3                 SMIN26 3                 SMIN27 3              
   SMIN28 3                 SMIN29 3                 SMIN30 3              
   SMIN31 3                 SMIN32 3                 SMIN33 3              
   SMIN34 3                 SMIN35 3                 SMIN36 3              
   SMIN37 3                 SMIN38 3 ;

        

RUN ;
